// Snippet from https://github.com/haecker-felix/hebbot, licensed under AGPL, License terms apply
#[allow(clippy::module_inception)]
pub mod utils {
    use matrix_sdk::ruma::events::room::message::{
        MessageType, OriginalSyncRoomMessageEvent, TextMessageEventContent, Relation,
    };
    use matrix_sdk::ruma::OwnedEventId;
    use std::{
        fs::File,
        io::{copy, BufReader, BufRead, Result},
    };
    use reqwest;

    pub fn get_message_event_text(event: &OriginalSyncRoomMessageEvent) -> Option<String> {
        if let MessageType::Text(TextMessageEventContent { body, .. }) = &event.content.msgtype {
            Some(body.to_owned())
        } else {
            None
        }
    }

    // A simplified way of getting an edited message
    pub fn get_edited_message_event_text(
        event: &OriginalSyncRoomMessageEvent,
    ) -> Option<(OwnedEventId, String)> {
        if let Some(Relation::Replacement(r)) = &event.content.relates_to {
            if let MessageType::Text(TextMessageEventContent { body, .. }) = &r.new_content.msgtype {
                return Some((r.event_id.clone(), body.to_owned()));
            }
        }

        None
    }

    pub fn create_swear_list(swear_list_url: &str) -> Result<Vec<String>> {
        // Downloads the text file
        let resp = reqwest::blocking::get(swear_list_url).expect("request failed");
        let body = resp.text().expect("Invalid Body");
        let mut out = File::create("list.txt").expect("failed to create file");
        copy(&mut body.as_bytes(), &mut out).expect("failed to copy content");

        // Reads file, returns vector of Strings through collecting iterator
        BufReader::new(File::open("list.txt")?).lines().collect()
    }
}
